@@ -1,7 +1,6 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2006, Jamie McCracken <jamiemcc@gnome.org>
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -178,6 +177,23 @@ tracker_dbus_register_objects (gpointer object)
 	return TRUE;
 }
 
+gboolean
+tracker_dbus_connection_add_filter (DBusHandleMessageFunction  function,
+                                    void                      *user_data)
+{
+	if (!connection) {
+		g_critical ("D-Bus support must be initialized before adding connection filters!");
+		return FALSE;
+	}
+
+	dbus_connection_add_filter (dbus_g_connection_get_connection (connection),
+	                            function,
+	                            user_data,
+	                            NULL);
+
+	return TRUE;
+}
+
 GObject *
 tracker_dbus_get_object (GType type)
 {
